# pyDGSA

pyDGSA is a Python implementation of distance-based generalized sensitivity analysis (DGSA) following [Fenwick et al. (2014)](https://doi.org/10.1007/s11004-014-9530-5).

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pyDGSA.

```bash
pip install pyDGSA
```

## Usage
Please see the `tutorial_short.ipynb` and `tutorial_long.ipynb` Jupyter notebooks in the [pyDGSA GitHub repository](https://github.com/zperzan/pyDGSA) for detailed usage examples.

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[GPL](https://choosealicense.com/licenses/gpl-3.0/)
